@@ -1,8 +1,7 @@
 from asyncio import Lock
 from importlib.util import find_spec
-from typing import Any, Generic, Self, TypeVar
+from typing import Any, Self
 
-from kubernetes_asyncio.client import ApiException, V1ConfigMap, V1ObjectMeta
 from pydantic import BaseModel
 
 from bs_state import AccessException, MissingStateException, StateStorage
@@ -11,11 +10,10 @@ if find_spec("kubernetes_asyncio") is None:
     raise RuntimeError("Requires extra 'kubernetes', i.e. bs-state[kubernetes]")
 
 from kubernetes_asyncio import client, config
-
-T = TypeVar("T", bound=BaseModel)
+from kubernetes_asyncio.client import ApiException, V1ConfigMap, V1ObjectMeta
 
 
-async def load(
+async def load[T: BaseModel](
     *,
     initial_state: T,
     namespace: str,
@@ -30,7 +28,7 @@ async def load(
     )
 
 
-class _ConfigMapStateStorage(StateStorage[T], Generic[T]):
+class _ConfigMapStateStorage[T: BaseModel](StateStorage[T]):
     DATA_KEY = "state"
 
     def __init__(
